// Copyright (c) 2022 Dominic Masters
// 
// This software is released under the MIT License.
// https://opensource.org/licenses/MIT

#pragma once
#include "PokerVNScene.hpp"
#include "prefabs/VNPenny.hpp"

namespace Dawn {
  class TestScene : public PokerVNScene {
    protected:
      SceneItem *penny;
      SceneItem *julie;
      SceneItem *sammy;
      SceneItem *lucy;

      void vnStage() override {
        penny = VNPenny::create(this);
        julie = VNPenny::create(this);
        sammy = VNPenny::create(this);
        lucy = VNPenny::create(this);

        PokerVNScene::vnStage();
      }

      std::vector<PokerPlayer *> getPokerPlayers() override {
        return std::vector<PokerPlayer*>{
          this->penny->getComponent<PokerPlayer>(),
          this->julie->getComponent<PokerPlayer>(),
          this->sammy->getComponent<PokerPlayer>(),
          this->lucy->getComponent<PokerPlayer>()
        };
      }

      IVisualNovelEvent * getVNEvent() override {
        auto texture = this->game->assetManager.get<TextureAsset>("texture_tavern_night");

        auto start = new VisualNovelChangeSimpleBackgroundEvent(
          vnManager, &texture->texture
        );
        
        struct Locale loc;
        loc.language = "fr";
        this->game->localeManager.setLocale(loc);

        start
          ->then(new VisualNovelTextboxEvent(vnManager, "test"))
          ->then(new PokerNewGameEvent(vnManager))
          ->then(new VisualNovelTextboxEvent(vnManager, "test"))
          ->then(new PokerInitialEvent(vnManager))
        ;

        return start;
      }

    public:
      TestScene(DawnGame *game) : PokerVNScene(game) {

      }

      std::vector<Asset*> getRequiredAssets() override {
        auto assMan = &this->game->assetManager;
        std::vector<Asset*> assets;
        vectorAppend(&assets, &PokerVNScene::getRequiredAssets());
        vectorAppend(&assets, &VNPenny::getAssets(assMan));
        assets.push_back(assMan->get<TextureAsset>("texture_tavern_night"));
        return assets;
      }
  };
}